<?xml version="1.0" ?><!DOCTYPE TS><TS language="da_DK" version="2.0">
<context>
    <name>QuickLaunchButton</name>
    <message>
        <source>Move left</source>
        <translation>Flyt mod venstre</translation>
    </message>
    <message>
        <source>Move right</source>
        <translation>Flyt mod højre</translation>
    </message>
    <message>
        <source>Remove from quicklaunch</source>
        <translation>Fjern fra quicklaunch</translation>
    </message>
</context>
<context>
    <name>RazorQuickLaunch</name>
    <message>
        <source>Drop Error</source>
        <translation>Træk og slip fejl</translation>
    </message>
    <message>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Fil/URL &apos;%1&apos; kan ikke blive indlejret i QuickLaunch lige nu</translation>
    </message>
</context>
</TS>